@@ -466,3 +466,10 @@ class VariableClInstallKernelUid(ReadonlyVariable):
 
     def get(self):
         return getKernelUid(self.Get('os_install_root_dev'))
+
+
+class VariableClInstallKernelBuild(Variable):
+    """
+    Переменная используемся для GRP дистрибутивов и сборки нескольких ядер
+    """
+    value = ""
