@@ -29,7 +29,7 @@ from calculate.core.server.func import WsdlBase
 from calculate.install.utils.cl_install import ClInstallAction
 from calculate.install.utils.cl_setup import (
     ClSetupLocaleAction, ClSetupVideoAction, ClSetupSystemAction,
-    ClSetupBootAction, ClSetupNetworkAction,
+    ClSetupBootAction, ClSetupNetworkAction, ClSetupAudioAction,
     ClSetupSessionAction)
 
 
@@ -112,6 +112,9 @@ class Wsdl(WsdlBase):
                                 expert=('cl_install_home_crypt_set',),
                                 hide=('cl_migrate_data',),
                                 brief=('cl_migrate_data_brief',)),
+            lambda group: group(_("Audio"),
+                                    normal=('os_audio',),
+                                    expert=('os_audio_default',)),
             lambda group: group(_("Video"),
                                 normal=('os_install_x11_video_drv',
                                         'os_install_x11_composite',
@@ -288,6 +291,31 @@ class Wsdl(WsdlBase):
                                         'cl_dispatch_conf',
                                         'cl_verbose_set'),
                                     next_label=_("Save"))]},
+        {
+            # настройка звука
+            'method_name': "setup_audio",
+            'category': __("Configuration"),
+            'title': __("Audio"),
+            'image': 'audio-card',
+            'command': 'cl-setup-audio',
+            'gui': True,
+            'rights': ['setupaudio'],
+            'logic': {'Install': install.Install},
+            'action': ClSetupAudioAction,
+            'datavars': "install",
+            'native_error': (
+                VariableError, DataVarsError, install.InstallError),
+            'setvars': {'cl_action!': 'merge', 'cl_merge_pkg!': [None],
+                        'cl_merge_set!': "on", 'cl_setup': 'audio'},
+            'groups': [
+                lambda group: group(_("Audio"),
+                                    normal=('os_audio',),
+                                    expert=(
+                                        'os_audio_default',
+                                        'cl_templates_locate',
+                                        'cl_dispatch_conf',
+                                        'cl_verbose_set'),
+                                    next_label=_("Save"))]},
         {
             # настройка локали
             'method_name': "setup_locale",
